USE cw3_CleanItSupply
GO

----****************************
----Define vars, views, functions and defaults
----****************************
CREATE VIEW _vRandom AS SELECT RAND() AS Random
GO
CREATE FUNCTION GetRandom() RETURNS Float AS BEGIN RETURN (SELECT .23 + (SELECT Random FROM _vRandom) * (.27-.23)) END 
GO

DECLARE @ScrapeImport NVarChar(200), @ImportPath NVarChar(200), @Sql NVarChar(MAX)

SET @ImportPath = 'C:\temp\Price_Update_11_09_2012\'
SET @ScrapeImport = @ImportPath+'1000_1.txt'

----****************************
----Create temp table for Scrape
----****************************
CREATE TABLE #Scrape ( [VariantID] [NVarChar](50) NULL, [Sku] [NVarChar](50) NULL, [NewCost] [NVarChar](50) NULL, [CSEPrice] [NVarChar](50) NULL ) 

----****************************
----Execute dynamic sql to bulk load import to temp table
----****************************
SET @Sql = ' BULK INSERT #Scrape FROM '''+@ScrapeImport+''' WITH ( FIELDTERMINATOR = ''|'', ROWTERMINATOR = ''\n'' ) '
EXEC sp_ExecuteSQL @Sql

----****************************
----	Cleanup Import
----****************************
DELETE FROM #Scrape WHERE Sku='Sku'

----****************************
----	Update SalePrice with Scrape
----****************************
UPDATE ProductVariant SET SalePrice=0

UPDATE #Scrape SET NewCost=REPLACE(NewCost,'"','')
UPDATE #Scrape SET NewCost=REPLACE(NewCost,',','')
----****************************
----	Update New Cost 
----****************************

UPDATE pv
SET pv.Cost=ROUND(s.NewCost,2)
FROM ProductVariant pv 
	INNER JOIN #Scrape s ON pv.VariantID=s.VariantID

----****************************
----	Update Regular Price based on Scrapes
----****************************

UPDATE pv
SET pv.Price=ROUND(CAST(s.CSEPrice AS Money)*1.18,2)
FROM ProductVariant pv 
	INNER JOIN #Scrape s ON pv.VariantID=s.VariantID

----****************************
----	Update Msrp
----****************************
UPDATE pv 
SET pv.MSRP = ROUND(pv.Price/(1-(SELECT dbo.GetRandom())),2)
FROM ProductVariant pv 
	INNER JOIN #Scrape s ON pv.VariantID=s.VariantID

----****************************
----	Amazon Extended Pricing Update
----****************************

update ExtendedPrice
set Price=ROUND(pv.Price*1.12,2)
FROM ExtendedPrice INNER JOIN ProductVariant pv ON ExtendedPrice.VariantID= pv.VariantID
	INNER JOIN #Scrape s ON pv.VariantID=s.VariantID where CustomerLevelID=112

----****************************
----	CSE Pricing Program Extended Pricing Update
----****************************

update ExtendedPrice
set Price=ROUND(CAST(s.CSEPrice AS Money),2)
FROM ExtendedPrice INNER JOIN ProductVariant pv ON ExtendedPrice.VariantID= pv.VariantID
	INNER JOIN #Scrape s ON pv.VariantID=s.VariantID where CustomerLevelID=115

----****************************
----	CSE Pricing Program (Manual Set) Extended Pricing Update
----****************************

update ExtendedPrice
set Price=ROUND(CAST(s.CSEPrice AS Money),2)
FROM ExtendedPrice INNER JOIN ProductVariant pv ON ExtendedPrice.VariantID= pv.VariantID
	INNER JOIN #Scrape s ON pv.VariantID=s.VariantID where CustomerLevelID=116

----****************************
----	CSE Pricing Program (Manual Set - Local) Extended Pricing Update
----****************************

update ExtendedPrice
set Price=ROUND(CAST(s.CSEPrice AS Money),2)
FROM ExtendedPrice INNER JOIN ProductVariant pv ON ExtendedPrice.VariantID= pv.VariantID
	INNER JOIN #Scrape s ON pv.VariantID=s.VariantID where CustomerLevelID=117

----****************************
----	CSE Pricing Program (Manual Set - TaxExempt) Extended Pricing Update
----****************************

update ExtendedPrice
set Price=ROUND(CAST(s.CSEPrice AS Money),2)
FROM ExtendedPrice INNER JOIN ProductVariant pv ON ExtendedPrice.VariantID= pv.VariantID
	INNER JOIN #Scrape s ON pv.VariantID=s.VariantID where CustomerLevelID=118

----****************************
----	CSE Pricing Program (Manual Set - Local - TaxExempt) Extended Pricing Update
----****************************

update ExtendedPrice
set Price=ROUND(CAST(s.CSEPrice AS Money),2)
FROM ExtendedPrice INNER JOIN ProductVariant pv ON ExtendedPrice.VariantID= pv.VariantID
	INNER JOIN #Scrape s ON pv.VariantID=s.VariantID where CustomerLevelID=119

----****************************
----	CSE Pricing Program (Manual Set) - Michigan Extended Pricing Update
----****************************

update ExtendedPrice
set Price=ROUND(CAST(s.CSEPrice AS Money),2)
FROM ExtendedPrice INNER JOIN ProductVariant pv ON ExtendedPrice.VariantID= pv.VariantID
	INNER JOIN #Scrape s ON pv.VariantID=s.VariantID where CustomerLevelID=123

	----****************************
----	Reseller - Michigan (12%)
----****************************

update ExtendedPrice
set Price=ROUND((pv.Cost/(1-.12)),2)
FROM ExtendedPrice INNER JOIN ProductVariant pv ON ExtendedPrice.VariantID= pv.VariantID
	INNER JOIN #Scrape s ON pv.VariantID=s.VariantID where CustomerLevelID=149

----****************************
----	Michigan - Special Pricing (15%)
----****************************

update ExtendedPrice
set Price=ROUND((pv.Cost/(1-.15)),2)
FROM ExtendedPrice INNER JOIN ProductVariant pv ON ExtendedPrice.VariantID= pv.VariantID
	INNER JOIN #Scrape s ON pv.VariantID=s.VariantID where CustomerLevelID=126

----****************************
----	Michigan - Special Pricing (20%)
----****************************

update ExtendedPrice
set Price=ROUND((pv.Cost/(1-.20)),2)
FROM ExtendedPrice INNER JOIN ProductVariant pv ON ExtendedPrice.VariantID= pv.VariantID
	INNER JOIN #Scrape s ON pv.VariantID=s.VariantID where CustomerLevelID=147

----****************************
----	Process Cleanup
----****************************
DROP TABLE #Scrape
DROP FUNCTION GetRandom
DROP VIEW _vRandom

